.. _contact:

CONTACT
#######

.. image:: ../jpg/bart.jpg
    :scale: 10%
    :align: right

| Bartholomeus Henricus Julius Thate (bart) - :ref:`evrm <evrm>`
| botfather on #dunkbots irc.freenode.net
| bthate@dds.nl, thatebart@gmail.com

| MADS is een event logger, zie :ref:`loggen <loggen>`
